@@ -12,7 +12,7 @@ class Angular(Platform):
 
             # Build with Angular
             status.update(status='Installing npm dependencies...')
-            call(self.console, '~/.nvm/nvm.sh use')  # This needs chmod +x, hacky!
+            call(self.console, '~/.nvm/nvm.sh use')  # todo: This needs chmod +x, hacky!
             call(self.console, 'npm install')
             self.console.log(':white_check_mark: Installed npm dependencies.')
 
